@@ -1,24 +1,21 @@
 // -------------------------------------------------------------------
-// Copyright (c) 2013-2017, AIT Austrian Institute of Technology GmbH.
+// Copyright (c) 2013-2022, AIT Austrian Institute of Technology GmbH.
 // All rights reserved. See file FMIPP_LICENSE for details.
 // -------------------------------------------------------------------
 
 #ifndef _FMIPP_FMICOMPONENTBACKEND_H
 #define _FMIPP_FMICOMPONENTBACKEND_H
 
-#include <string>
 #include <vector>
 #include <sstream>
 #include <map>
 
-#include "common/fmi_v2.0/fmi2ModelTypes.h"
 #include "common/FMIPPConfig.h"
-#include "common/FMUType.h"
 
 #include "export/include/ScalarVariable.h"
 #include "export/include/IPCSlave.h"
 #include "export/include/IPCSlaveLogger.h"
-
+#include "export/include/IPCString.h"
 
 /**
  * \file FMIComponentBackEnd.h
@@ -40,156 +37,156 @@ public:
 	///
 	/// Start initialization of the backend (connect/sync with master).
 	///
-	fmi2Status startInitialization();
+	fmippStatus startInitialization();
 
 	///
 	/// End initialization of the backend (connect/sync with master).
 	///
-	fmi2Status endInitialization();
+	fmippStatus endInitialization();
 
 	///
 	/// Initialize real parameters.
 	/// Intended to be called after #startInitialization and before #endInitialization.
 	///
-	fmi2Status initializeRealParameters( const std::vector<std::string>& names, std::vector<fmi2Real*>& params );
+	fmippStatus initializeRealParameters( const std::vector<fmippString>& names, std::vector<fmippReal*>& params );
 
 	///
 	/// Initialize real parameters.
 	/// Intended to be called after #startInitialization and before #endInitialization.
 	///
-	fmi2Status initializeRealParameters( const std::string* names, fmi2Real* params, const size_t n );
+	fmippStatus initializeRealParameters( const fmippString* names, fmippReal* params, const size_t n );
 
 	///
 	/// Initialize integer parameters.
 	/// Intended to be called after #startInitialization and before #endInitialization.
 	///
-	fmi2Status initializeIntegerParameters( const std::vector<std::string>& names, std::vector<fmi2Integer*>& params );
+	fmippStatus initializeIntegerParameters( const std::vector<fmippString>& names, std::vector<fmippInteger*>& params );
 
 	///
 	/// Initialize integer parameters.
 	/// Intended to be called after #startInitialization and before #endInitialization.
 	///
-	fmi2Status initializeIntegerParameters( const std::string* names, fmi2Integer* params, const size_t n );
+	fmippStatus initializeIntegerParameters( const fmippString* names, fmippInteger* params, const size_t n );
 
 	///
 	/// Initialize boolean parameters.
 	/// Intended to be called after #startInitialization and before #endInitialization.
 	///
-	fmi2Status initializeBooleanParameters( const std::vector<std::string>& names, std::vector<fmi2Boolean*>& params );
+	fmippStatus initializeBooleanParameters( const std::vector<fmippString>& names, std::vector<fmippBoolean*>& params );
 
 	///
 	/// Initialize boolean parameters.
 	/// Intended to be called after #startInitialization and before #endInitialization.
 	///
-	fmi2Status initializeBooleanParameters( const std::string* names, fmi2Boolean* params, const size_t n );
+	fmippStatus initializeBooleanParameters( const fmippString* names, fmippBoolean* params, const size_t n );
 
 	///
 	/// Initialize string parameters.
 	/// Intended to be called after #startInitialization and before #endInitialization.
 	///
-	fmi2Status initializeStringParameters( const std::vector<std::string>& names, std::vector<std::string*>& params );
+	fmippStatus initializeStringParameters( const std::vector<fmippString>& names, std::vector<fmippString*>& params );
 
 	///
 	/// Initialize string parameters.
 	/// Intended to be called after #startInitialization and before #endInitialization.
 	///
-	fmi2Status initializeStringParameters( const std::string* names, std::string* params, const size_t n );
+	fmippStatus initializeStringParameters( const fmippString* names, fmippString* params, const size_t n );
 
 	///
 	/// Initialize real variables for input.
 	/// Intended to be called after #startInitialization and before #endInitialization.
 	///
-	fmi2Status initializeRealInputs( const std::vector<std::string>& names, std::vector<fmi2Real*>& inputs );
+	fmippStatus initializeRealInputs( const std::vector<fmippString>& names, std::vector<fmippReal*>& inputs );
 
 	///
 	/// Initialize real variables for input.
 	/// Intended to be called after #startInitialization and before #endInitialization.
 	///
-	fmi2Status initializeRealInputs( const std::string* names, fmi2Real* inputs, const size_t n );
+	fmippStatus initializeRealInputs( const fmippString* names, fmippReal* inputs, const size_t n );
 
 	///
 	/// Initialize integer variables for input.
 	/// Intended to be called after #startInitialization and before #endInitialization.
 	///
-	fmi2Status initializeIntegerInputs( const std::vector<std::string>& names, std::vector<fmi2Integer*>& inputs );
+	fmippStatus initializeIntegerInputs( const std::vector<fmippString>& names, std::vector<fmippInteger*>& inputs );
 
 	///
 	/// Initialize integer variables for input.
 	/// Intended to be called after #startInitialization and before #endInitialization.
 	///
-	fmi2Status initializeIntegerInputs( const std::string* names, fmi2Integer* inputs, const size_t n );
+	fmippStatus initializeIntegerInputs( const fmippString* names, fmippInteger* inputs, const size_t n );
 
 	///
 	/// Initialize boolean variables for input.
 	/// Intended to be called after #startInitialization and before #endInitialization.
 	///
-	fmi2Status initializeBooleanInputs( const std::vector<std::string>& names, std::vector<fmi2Boolean*>& inputs );
+	fmippStatus initializeBooleanInputs( const std::vector<fmippString>& names, std::vector<fmippBoolean*>& inputs );
 
 	///
 	/// Initialize boolean variables for input.
 	/// Intended to be called after #startInitialization and before #endInitialization.
 	///
-	fmi2Status initializeBooleanInputs( const std::string* names, fmi2Boolean* inputs, const size_t n );
+	fmippStatus initializeBooleanInputs( const fmippString* names, fmippBoolean* inputs, const size_t n );
 
 	///
 	/// Initialize string variables for input.
 	/// Intended to be called after #startInitialization and before #endInitialization.
 	///
-	fmi2Status initializeStringInputs( const std::vector<std::string>& names, std::vector<std::string*>& inputs );
+	fmippStatus initializeStringInputs( const std::vector<fmippString>& names, std::vector<fmippString*>& inputs );
 
 	///
 	/// Initialize string variables for input.
 	/// Intended to be called after #startInitialization and before #endInitialization.
 	///
-	fmi2Status initializeStringInputs( const std::string* names, std::string* inputs, const size_t n );
+	fmippStatus initializeStringInputs( const fmippString* names, fmippString* inputs, const size_t n );
 
 	///
 	/// Initialize real variables for output.
 	/// Intended to be called after #startInitialization and before #endInitialization.
 	///
-	fmi2Status initializeRealOutputs( const std::vector<std::string>& names, std::vector<fmi2Real*>& outputs );
+	fmippStatus initializeRealOutputs( const std::vector<fmippString>& names, std::vector<fmippReal*>& outputs );
 
 	///
 	/// Initialize real variables for output.
 	/// Intended to be called after #startInitialization and before #endInitialization.
 	///
-	fmi2Status initializeRealOutputs( const std::string* names, fmi2Real* outputs, const size_t n );
+	fmippStatus initializeRealOutputs( const fmippString* names, fmippReal* outputs, const size_t n );
 
 	///
 	/// Initialize integer variables for output.
 	/// Intended to be called after #startInitialization and before #endInitialization.
 	///
-	fmi2Status initializeIntegerOutputs( const std::vector<std::string>& names, std::vector<fmi2Integer*>& outputs );
+	fmippStatus initializeIntegerOutputs( const std::vector<fmippString>& names, std::vector<fmippInteger*>& outputs );
 
 	///
 	/// Initialize integer variables for output.
 	/// Intended to be called after #startInitialization and before #endInitialization.
 	///
-	fmi2Status initializeIntegerOutputs( const std::string* names, fmi2Integer* outputs, const size_t n );
+	fmippStatus initializeIntegerOutputs( const fmippString* names, fmippInteger* outputs, const size_t n );
 
 	///
 	/// Initialize boolean variables for output.
 	/// Intended to be called after #startInitialization and before #endInitialization.
 	///
-	fmi2Status initializeBooleanOutputs( const std::vector<std::string>& names, std::vector<fmi2Boolean*>& outputs );
+	fmippStatus initializeBooleanOutputs( const std::vector<fmippString>& names, std::vector<fmippBoolean*>& outputs );
 
 	///
 	/// Initialize boolean variables for output.
 	/// Intended to be called after #startInitialization and before #endInitialization.
 	///
-	fmi2Status initializeBooleanOutputs( const std::string* names, fmi2Boolean* outputs, const size_t n );
+	fmippStatus initializeBooleanOutputs( const fmippString* names, fmippBoolean* outputs, const size_t n );
 
 	///
 	/// Initialize boolean variables for output.
 	/// Intended to be called after #startInitialization and before #endInitialization.
 	///
-	fmi2Status initializeStringOutputs( const std::vector<std::string>& names, std::vector<std::string*>& outputs );
+	fmippStatus initializeStringOutputs( const std::vector<fmippString>& names, std::vector<fmippString*>& outputs );
 
 	///
 	/// Initialize boolean variables for output.
 	/// Intended to be called after #startInitialization and before #endInitialization.
 	///
-	fmi2Status initializeStringOutputs( const std::string* names, std::string* outputs, const size_t n );
+	fmippStatus initializeStringOutputs( const fmippString* names, fmippString* outputs, const size_t n );
 
 	///
 	/// Wait for signal from master to resume execution.
@@ -208,176 +205,168 @@ public:
 	/// Parameters are assumed to be in the same order as specified by #initializeRealParameters.
 	/// Call this method only between calls to #waitForMaster and #signalToMaster.
 	///
-	fmi2Status getRealParameters( std::vector<fmi2Real*>& parameters );
+	fmippStatus getRealParameters( std::vector<fmippReal*>& parameters );
 
 	///
 	/// Read values from real parameters.
 	/// Parameters are assumed to be in the same order as specified by #initializeRealParameters.
 	/// Call this method only between calls to #waitForMaster and #signalToMaster.
 	///
-	fmi2Status getRealParameters( fmi2Real* parameters, size_t nParameters );
+	fmippStatus getRealParameters( fmippReal* parameters, size_t nParameters );
 
 	///
 	/// Read values from integer parameters.
 	/// Parameters are assumed to be in the same order as specified by #initializeIntegerParameters.
 	/// Call this method only between calls to #waitForMaster and #signalToMaster.
 	///
-	fmi2Status getIntegerParameters( std::vector<fmi2Integer*>& parameters );
+	fmippStatus getIntegerParameters( std::vector<fmippInteger*>& parameters );
 
 	///
 	/// Read values from integer parameters.
 	/// Parameters are assumed to be in the same order as specified by #initializeIntegerParameters.
 	/// Call this method only between calls to #waitForMaster and #signalToMaster.
 	///
-	fmi2Status getIntegerParameters( fmi2Integer* parameters, size_t nParameters );
+	fmippStatus getIntegerParameters( fmippInteger* parameters, size_t nParameters );
 
 	///
 	/// Read values from boolean parameters.
 	/// Parameters are assumed to be in the same order as specified by #initializeBoolParameters.
 	/// Call this method only between calls to #waitForMaster and #signalToMaster.
 	///
-	fmi2Status getBooleanParameters( std::vector<fmi2Boolean*>& parameters );
+	fmippStatus getBooleanParameters( std::vector<fmippBoolean*>& parameters );
 
 	///
 	/// Read values from boolean parameters.
 	/// Parameters are assumed to be in the same order as specified by #initializeBoolParameters.
 	/// Call this method only between calls to #waitForMaster and #signalToMaster.
 	///
-	fmi2Status getBooleanParameters( fmi2Boolean* parameters, size_t nParameters );
+	fmippStatus getBooleanParameters( fmippBoolean* parameters, size_t nParameters );
 
 	///
 	/// Read values from string parameters.
 	/// Parameters are assumed to be in the same order as specified by #initializeBoolParameters.
 	/// Call this method only between calls to #waitForMaster and #signalToMaster.
-	/// Attention: Uses std::string instead of fmi2String!
 	///
-	fmi2Status getStringParameters( std::vector<std::string*>& parameters );
+	fmippStatus getStringParameters( std::vector<fmippString*>& parameters );
 
 	///
 	/// Read values from string parameters.
 	/// Parameters are assumed to be in the same order as specified by #initializeBoolParameters.
 	/// Call this method only between calls to #waitForMaster and #signalToMaster.
-	/// Attention: Uses std::string instead of fmi2String!
 	///
-	fmi2Status getStringParameters( std::string* parameters, size_t nParameters );
-
+	fmippStatus getStringParameters( fmippString* parameters, size_t nParameters );
 
 	///
 	/// Specify values of real parameters.
 	/// Inputs are assumed to be in the same order as specified by #initializeRealParameters.
 	/// This method is supposed to be called only during the initializatiob phase.
 	///
-	fmi2Status setRealParameters( const std::vector<fmi2Real*>& parameters );
+	fmippStatus setRealParameters( const std::vector<fmippReal*>& parameters );
 
 	///
 	/// Specify values of real parameters.
 	/// Inputs are assumed to be in the same order as specified by #initializeRealParameters.
 	/// This method is supposed to be called only during the initializatiob phase.
 	///
-	fmi2Status setRealParameters( const fmi2Real* parameters, size_t nParameters );
+	fmippStatus setRealParameters( const fmippReal* parameters, size_t nParameters );
 
 	///
 	/// Specify values of integer parameters.
 	/// Inputs are assumed to be in the same order as specified by #initializeIntegerParameters.
 	/// This method is supposed to be called only during the initializatiob phase.
 	///
-	fmi2Status setIntegerParameters( const std::vector<fmi2Integer*>& parameters );
+	fmippStatus setIntegerParameters( const std::vector<fmippInteger*>& parameters );
 
 	///
 	/// Specify values of integer parameters.
 	/// Inputs are assumed to be in the same order as specified by #initializeIntegerParameters.
 	/// This method is supposed to be called only during the initializatiob phase.
 	///
-	fmi2Status setIntegerParameters( const fmi2Integer* parameters, size_t nParameters );
+	fmippStatus setIntegerParameters( const fmippInteger* parameters, size_t nParameters );
 
 	///
 	/// Specify values of boolean parameters.
 	/// Inputs are assumed to be in the same order as specified by #initializeBooleanParameters.
 	/// This method is supposed to be called only during the initializatiob phase.
 	///
-	fmi2Status setBooleanParameters( const std::vector<fmi2Boolean*>& parameters );
+	fmippStatus setBooleanParameters( const std::vector<fmippBoolean*>& parameters );
 
 	///
 	/// Specify values of boolean parameters.
 	/// Inputs are assumed to be in the same order as specified by #initializeBooelanParameters.
 	/// This method is supposed to be called only during the initializatiob phase.
 	///
-	fmi2Status setBooleanParameters( const fmi2Boolean* parameters, size_t nParameters );
+	fmippStatus setBooleanParameters( const fmippBoolean* parameters, size_t nParameters );
 
 	///
 	/// Specify values of string parameters.
 	/// Inputs are assumed to be in the same order as specified by #initializeStringParameters.
 	/// This method is supposed to be called only during the initializatiob phase.
-	/// Attention: Uses std::string instead of fmi2String!
 	///
-	fmi2Status setStringParameters( const std::vector<std::string*>& parameters );
+	fmippStatus setStringParameters( const std::vector<fmippString*>& parameters );
 
 	///
 	/// Specify values of string parameters.
 	/// Inputs are assumed to be in the same order as specified by #initializeStringParameters.
 	/// This method is supposed to be called only during the initializatiob phase.
-	/// Attention: Uses std::string instead of fmi2String!
 	///
-	fmi2Status setStringParameters( const std::string* parameters, size_t nParameters );
-
+	fmippStatus setStringParameters( const fmippString* parameters, size_t nParameters );
 
 	///
 	/// Read values from real inputs.
 	/// Inputs are assumed to be in the same order as specified by #initializeRealInputs.
 	/// Call this method only between calls to #waitForMaster and #signalToMaster.
 	///
-	fmi2Status getRealInputs( std::vector<fmi2Real*>& inputs );
+	fmippStatus getRealInputs( std::vector<fmippReal*>& inputs );
 
 	///
 	/// Read values from real inputs.
 	/// Inputs are assumed to be in the same order as specified by #initializeRealInputs.
 	/// Call this method only between calls to #waitForMaster and #signalToMaster.
 	///
-	fmi2Status getRealInputs( fmi2Real* inputs, size_t nInputs );
+	fmippStatus getRealInputs( fmippReal* inputs, size_t nInputs );
 
 	///
 	/// Read values from integer inputs.
 	/// Inputs are assumed to be in the same order as specified by #initializeIntegerInputs.
 	/// Call this method only between calls to #waitForMaster and #signalToMaster.
 	///
-	fmi2Status getIntegerInputs( std::vector<fmi2Integer*>& inputs );
+	fmippStatus getIntegerInputs( std::vector<fmippInteger*>& inputs );
 
 	///
 	/// Read values from integer inputs.
 	/// Inputs are assumed to be in the same order as specified by #initializeIntegerInputs.
 	/// Call this method only between calls to #waitForMaster and #signalToMaster.
 	///
-	fmi2Status getIntegerInputs( fmi2Integer* inputs, size_t nInputs );
+	fmippStatus getIntegerInputs( fmippInteger* inputs, size_t nInputs );
 
 	///
 	/// Read values from boolean inputs.
 	/// Inputs are assumed to be in the same order as specified by #initializeBoolInputs.
 	/// Call this method only between calls to #waitForMaster and #signalToMaster.
 	///
-	fmi2Status getBooleanInputs( std::vector<fmi2Boolean*>& inputs );
+	fmippStatus getBooleanInputs( std::vector<fmippBoolean*>& inputs );
 
 	///
 	/// Read values from boolean inputs.
 	/// Inputs are assumed to be in the same order as specified by #initializeBoolInputs.
 	/// Call this method only between calls to #waitForMaster and #signalToMaster.
 	///
-	fmi2Status getBooleanInputs( fmi2Boolean* inputs, size_t nInputs );
+	fmippStatus getBooleanInputs( fmippBoolean* inputs, size_t nInputs );
 
 	///
 	/// Read values from string inputs.
 	/// Inputs are assumed to be in the same order as specified by #initializeBoolInputs.
 	/// Call this method only between calls to #waitForMaster and #signalToMaster.
-	/// Attention: Uses std::string instead of fmi2String!
 	///
-	fmi2Status getStringInputs( std::vector<std::string*>& inputs );
+	fmippStatus getStringInputs( std::vector<fmippString*>& inputs );
 
 	///
 	/// Read values from string inputs.
 	/// Inputs are assumed to be in the same order as specified by #initializeBoolInputs.
 	/// Call this method only between calls to #waitForMaster and #signalToMaster.
-	/// Attention: Uses std::string instead of fmi2String!
 	///
-	fmi2Status getStringInputs( std::string* inputs, size_t nInputs );
+	fmippStatus getStringInputs( fmippString* inputs, size_t nInputs );
 
 	///
 	/// Reset values of real inputs (i.e., overwrite values of input variables in the
@@ -385,7 +374,7 @@ public:
 	/// Inputs are assumed to be in the same order as specified by #initializeRealInputs.
 	/// Call this method only between calls to #waitForMaster and #signalToMaster.
 	///
-	fmi2Status resetRealInputs( std::vector<fmi2Real*>& inputs );
+	fmippStatus resetRealInputs( std::vector<fmippReal*>& inputs );
 
 	///
 	/// Reset values of real inputs (i.e., overwrite values of input variables in the
@@ -393,7 +382,7 @@ public:
 	/// Inputs are assumed to be in the same order as specified by #initializeRealInputs.
 	/// Call this method only between calls to #waitForMaster and #signalToMaster.
 	///
-	fmi2Status resetRealInputs( fmi2Real* inputs, size_t nInputs );
+	fmippStatus resetRealInputs( fmippReal* inputs, size_t nInputs );
 
 	///
 	/// Reset values of integer inputs (i.e., overwrite values of input variables in the
@@ -401,7 +390,7 @@ public:
 	/// Inputs are assumed to be in the same order as specified by #initializeIntegerInputs.
 	/// Call this method only between calls to #waitForMaster and #signalToMaster.
 	///
-	fmi2Status resetIntegerInputs( std::vector<fmi2Integer*>& inputs );
+	fmippStatus resetIntegerInputs( std::vector<fmippInteger*>& inputs );
 
 	///
 	/// Reset values of integer inputs (i.e., overwrite values of input variables in the
@@ -409,7 +398,7 @@ public:
 	/// Inputs are assumed to be in the same order as specified by #initializeIntegerInputs.
 	/// Call this method only between calls to #waitForMaster and #signalToMaster.
 	///
-	fmi2Status resetIntegerInputs( fmi2Integer* inputs, size_t nInputs );
+	fmippStatus resetIntegerInputs( fmippInteger* inputs, size_t nInputs );
 
 	///
 	/// Reset values of boolean inputs (i.e., overwrite values of input variables in the
@@ -417,7 +406,7 @@ public:
 	/// Inputs are assumed to be in the same order as specified by #initializeBoolInputs.
 	/// Call this method only between calls to #waitForMaster and #signalToMaster.
 	///
-	fmi2Status resetBooleanInputs( std::vector<fmi2Boolean*>& inputs );
+	fmippStatus resetBooleanInputs( std::vector<fmippBoolean*>& inputs );
 
 	///
 	/// Reset values of boolean inputs (i.e., overwrite values of input variables in the
@@ -425,89 +414,85 @@ public:
 	/// Inputs are assumed to be in the same order as specified by #initializeBoolInputs.
 	/// Call this method only between calls to #waitForMaster and #signalToMaster.
 	///
-	fmi2Status resetBooleanInputs( fmi2Boolean* inputs, size_t nInputs );
+	fmippStatus resetBooleanInputs( fmippBoolean* inputs, size_t nInputs );
 
 	///
 	/// Reset values of string inputs (i.e., overwrite values of input variables in the
 	/// frontend with values provided by the backend).
 	/// Inputs are assumed to be in the same order as specified by #initializeBoolInputs.
 	/// Call this method only between calls to #waitForMaster and #signalToMaster.
-	/// Attention: Uses std::string instead of fmi2String!
 	///
-	fmi2Status resetStringInputs( std::vector<std::string*>& inputs );
+	fmippStatus resetStringInputs( std::vector<fmippString*>& inputs );
 
 	///
 	/// Reset values of string inputs (i.e., overwrite values of input variables in the
 	/// frontend with values provided by the backend).
 	/// Inputs are assumed to be in the same order as specified by #initializeBoolInputs.
 	/// Call this method only between calls to #waitForMaster and #signalToMaster.
-	/// Attention: Uses std::string instead of fmi2String!
 	///
-	fmi2Status resetStringInputs( std::string* inputs, size_t nInputs );
+	fmippStatus resetStringInputs( fmippString* inputs, size_t nInputs );
 
 	///
 	/// Write values to real outputs.
 	/// Inputs are assumed to be in the same order as specified by #initializeRealOutputs.
 	/// Call this method only between calls to #waitForMaster and #signalToMaster.
 	///
-	fmi2Status setRealOutputs( const std::vector<fmi2Real*>& outputs );
+	fmippStatus setRealOutputs( const std::vector<fmippReal*>& outputs );
 
 	///
 	/// Write values to real outputs.
 	/// Inputs are assumed to be in the same order as specified by #initializeRealOutputs.
 	/// Call this method only between calls to #waitForMaster and #signalToMaster.
 	///
-	fmi2Status setRealOutputs( const fmi2Real* outputs, size_t nOutputs );
+	fmippStatus setRealOutputs( const fmippReal* outputs, size_t nOutputs );
 
 	///
 	/// Write values to integer outputs.
 	/// Inputs are assumed to be in the same order as specified by #initializeIntegerOutputs.
 	/// Call this method only between calls to #waitForMaster and #signalToMaster.
 	///
-	fmi2Status setIntegerOutputs( const std::vector<fmi2Integer*>& outputs );
+	fmippStatus setIntegerOutputs( const std::vector<fmippInteger*>& outputs );
 
 	///
 	/// Write values to integer outputs.
 	/// Inputs are assumed to be in the same order as specified by #initializeIntegerOutputs.
 	/// Call this method only between calls to #waitForMaster and #signalToMaster.
 	///
-	fmi2Status setIntegerOutputs( const fmi2Integer* outputs, size_t nOutputs );
+	fmippStatus setIntegerOutputs( const fmippInteger* outputs, size_t nOutputs );
 
 	///
 	/// Write values to boolean outputs.
 	/// Inputs are assumed to be in the same order as specified by #initializeBooleanOutputs.
 	/// Call this method only between calls to #waitForMaster and #signalToMaster.
 	///
-	fmi2Status setBooleanOutputs( const std::vector<fmi2Boolean*>& outputs );
+	fmippStatus setBooleanOutputs( const std::vector<fmippBoolean*>& outputs );
 
 	///
 	/// Write values to boolean outputs.
 	/// Inputs are assumed to be in the same order as specified by #initializeBooleanOutputs.
 	/// Call this method only between calls to #waitForMaster and #signalToMaster.
 	///
-	fmi2Status setBooleanOutputs( const fmi2Boolean* outputs, size_t nOutputs );
+	fmippStatus setBooleanOutputs( const fmippBoolean* outputs, size_t nOutputs );
 
 	///
 	/// Write values to string outputs.
 	/// Inputs are assumed to be in the same order as specified by #initializeStringOutputs.
 	/// Call this method only between calls to #waitForMaster and #signalToMaster.
-	/// Attention: Uses std::string instead of fmi2String!
 	///
-	fmi2Status setStringOutputs( const std::vector<std::string*>& outputs );
+	fmippStatus setStringOutputs( const std::vector<fmippString*>& outputs );
 
 	///
 	/// Write values to string outputs.
 	/// Inputs are assumed to be in the same order as specified by #initializeStringOutputs.
 	/// Call this method only between calls to #waitForMaster and #signalToMaster.
-	/// Attention: Uses std::string instead of fmi2String!
 	///
-	fmi2Status setStringOutputs( const std::string* outputs, size_t nOutputs );
+	fmippStatus setStringOutputs( const fmippString* outputs, size_t nOutputs );
 
 	///
 	/// Inform frontend what the next simulation time step will be.
 	/// Call this method only before #endInitialization or between calls to #waitForMaster and #signalToMaster.
 	///
-	void enforceTimeStep( const fmi2Real& delta );
+	void enforceTimeStep( const fmippReal& delta );
 
 	///
 	/// Inform frontend that the simulation step has been rejected.
@@ -515,28 +500,27 @@ public:
 	///
 	void rejectStep();
 
-
 	///
 	/// Call the internal logger.
 	///
-	void logger( fmi2Status status, const std::string& category, const std::string& msg );
+	void logger( fmippStatus status, const fmippString& category, const fmippString& msg );
 
 	///
 	/// Get current communication point from the front end.
 	/// Call this method only before #endInitialization or between calls to #waitForMaster and #signalToMaster.
 	///
-	const fmi2Real& getCurrentCommunicationPoint() const;
+	const fmippReal& getCurrentCommunicationPoint() const;
 
 	///
 	/// Get next communication step size from the front end.
 	/// Call this method only before #endInitialization or between calls to #waitForMaster and #signalToMaster.
 	///
-	const fmi2Real& getCommunicationStepSize() const;
+	const fmippReal& getCommunicationStepSize() const;
 
 	///
 	/// Get simulation stop time.
 	///
-	const fmi2Real& getStopTime() const;
+	const fmippReal& getStopTime() const;
 
 	///
 	/// Get flag indicating if simulation stop time has been defined.
@@ -546,55 +530,53 @@ public:
 	///
 	/// Get full path of log messages file.
 	///
-	std::string getLogFileName() const;
+	fmippString getLogFileName() const;
 
 	///
 	/// Check if logging has been activated.
 	///
 	bool loggingOn() const;
 
-
 	///
 	/// Get names of all real inputs initialized by the front end.
 	///
-	void getRealInputNames( std::vector<std::string>& names ) const;
+	void getRealInputNames( std::vector<fmippString>& names ) const;
 
 	///
 	/// Get names of all integer inputs initialized by the front end.
 	///
-	void getIntegerInputNames( std::vector<std::string>& names ) const;
+	void getIntegerInputNames( std::vector<fmippString>& names ) const;
 
 	///
 	/// Get names of all boolean inputs initialized by the front end.
 	///
-	void getBooleanInputNames( std::vector<std::string>& names ) const;
+	void getBooleanInputNames( std::vector<fmippString>& names ) const;
 
 	///
 	/// Get names of all string inputs initialized by the front end.
 	///
-	void getStringInputNames( std::vector<std::string>& names ) const;
+	void getStringInputNames( std::vector<fmippString>& names ) const;
 
 
 	///
 	/// Get names of all real outputs initialized by the front end.
 	///
-	void getRealOutputNames( std::vector<std::string>& names ) const;
+	void getRealOutputNames( std::vector<fmippString>& names ) const;
 
 	///
 	/// Get names of all integer outputs initialized by the front end.
 	///
-	void getIntegerOutputNames( std::vector<std::string>& names ) const;
+	void getIntegerOutputNames( std::vector<fmippString>& names ) const;
 
 	///
 	/// Get names of all boolean outputs initialized by the front end.
 	///
-	void getBooleanOutputNames( std::vector<std::string>& names ) const;
+	void getBooleanOutputNames( std::vector<fmippString>& names ) const;
 
 	///
 	/// Get names of all string outputs initialized by the front end.
 	///
-	void getStringOutputNames( std::vector<std::string>& names ) const;
-
+	void getStringOutputNames( std::vector<fmippString>& names ) const;
 
 private:
 
@@ -603,24 +585,24 @@ private:
 	/// parent process in case flag BACKEND_USE_PARENT_PID is
 	/// set at compilation time).
 	///
-	const std::string getProcessID() const;
+	const fmippString getProcessID() const;
 
 	///
 	/// Internal helper function for initialization of inputs/outputs.
 	///
 	template<typename Type>
-	fmi2Status initializeVariables( std::vector<Type*>& variablePointers,
-				       const std::string& scalarCollection,
-				       const std::vector<std::string>& scalarNames,
+	fmippStatus initializeVariables( std::vector<Type*>& variablePointers,
+				       const fmippString& scalarCollection,
+				       const std::vector<fmippString>& scalarNames,
 				       const ScalarVariableAttributes::Causality::Causality causality );
 
 	///
 	/// Internal helper function for initialization of inputs/outputs.
 	///
 	template<typename Type>
-	fmi2Status initializeVariables( std::vector<Type*>& variablePointers,
-				       const std::string& scalarCollection,
-				       const std::string* scalarNames,
+	fmippStatus initializeVariables( std::vector<Type*>& variablePointers,
+				       const fmippString& scalarCollection,
+				       const fmippString* scalarNames,
 					   const size_t nScalarNames,
 				       const ScalarVariableAttributes::Causality::Causality causality );
 
@@ -628,8 +610,8 @@ private:
 	/// Internal helper function for retrieving variable names.
 	///
 	template<typename Type>
-	void getScalarNames( std::vector<std::string>& scalarNames,
-			     const std::string& scalarCollection,
+	void getScalarNames( std::vector<fmippString>& scalarNames,
+			     const fmippString& scalarCollection,
 			     const ScalarVariableAttributes::Causality::Causality causality ) const;
 
 	///
@@ -650,17 +632,17 @@ private:
 	///
 	/// Simulation time as requested by the master.
 	///
-	fmi2Real* currentCommunicationPoint_;
+	fmippReal* currentCommunicationPoint_;
 
 	///
 	/// Next simulation time step size (requested by the master or enforced by the slave).
 	///
-	fmi2Real* communicationStepSize_;
+	fmippReal* communicationStepSize_;
 
 	///
 	/// Simulation stop time.
 	///
-	fmi2Real* stopTime_;
+	fmippReal* stopTime_;
 
 	///
 	/// Flag indicating if stop time has been defined.
@@ -695,93 +677,87 @@ private:
 	///
 	/// Internal pointers to real-valued parameters.
 	///
-	std::vector<fmi2Real*> realParameters_;
+	std::vector<fmippReal*> realParameters_;
 
 	///
 	/// Internal pointers to integer-valued parameters.
 	///
-	std::vector<fmi2Integer*> integerParameters_;
+	std::vector<fmippInteger*> integerParameters_;
 
 	///
 	/// Internal pointers to boolean-valued parameters.
 	///
-	std::vector<fmi2Boolean*> booleanParameters_;
+	std::vector<fmippBoolean*> booleanParameters_;
 
 	///
 	/// Internal pointers to string-valued parameters.
-	/// Attention: Uses std::string instead of fmi2String!
 	///
-	std::vector<std::string*> stringParameters_;
+	std::vector<fmippIPCString*> stringParameters_;
 
 	///
 	/// Internal pointers to real-valued inputs.
 	///
-	std::vector<fmi2Real*> realInputs_;
+	std::vector<fmippReal*> realInputs_;
 
 	///
 	/// Internal pointers to integer-valued inputs.
 	///
-	std::vector<fmi2Integer*> integerInputs_;
+	std::vector<fmippInteger*> integerInputs_;
 
 	///
 	/// Internal pointers to boolean-valued inputs.
 	///
-	std::vector<fmi2Boolean*> booleanInputs_;
+	std::vector<fmippBoolean*> booleanInputs_;
 
 	///
 	/// Internal pointers to string-valued inputs.
-	/// Attention: Uses std::string instead of fmi2String!
 	///
-	std::vector<std::string*> stringInputs_;
+	std::vector<fmippIPCString*> stringInputs_;
 
 	///
 	/// Internal pointers to real-valued outputs.
 	///
-	std::vector<fmi2Real*> realOutputs_;
+	std::vector<fmippReal*> realOutputs_;
 
 	///
 	/// Internal pointers to integer-valued outputs.
 	///
-	std::vector<fmi2Integer*> integerOutputs_;
+	std::vector<fmippInteger*> integerOutputs_;
 
 	///
 	/// Internal pointers to boolean-valued outputs.
 	///
-	std::vector<fmi2Boolean*> booleanOutputs_;
+	std::vector<fmippBoolean*> booleanOutputs_;
 
 	///
 	/// Internal pointers to string-valued outputs.
-	/// Attention: Uses std::string instead of fmi2String!
 	///
-	std::vector<std::string*> stringOutputs_;
+	std::vector<fmippIPCString*> stringOutputs_;
 };
 
-
-
 template<typename Type>
-fmi2Status FMIComponentBackEnd::initializeVariables( std::vector<Type*>& variablePointers,
-	const std::string& scalarCollection,
-	const std::string* scalarNames,
+fmippStatus FMIComponentBackEnd::initializeVariables( std::vector<Type*>& variablePointers,
+	const fmippString& scalarCollection,
+	const fmippString* scalarNames,
 	const size_t nScalarNames,
 	const ScalarVariableAttributes::Causality::Causality causality )
 {
-	std::vector<std::string> vecScalarNames( scalarNames, scalarNames + nScalarNames );
+	std::vector<fmippString> vecScalarNames( scalarNames, scalarNames + nScalarNames );
 	return initializeVariables( variablePointers, scalarCollection, vecScalarNames, causality );
 }
 
-
 template<typename Type>
-fmi2Status FMIComponentBackEnd::initializeVariables( std::vector<Type*>& variablePointers,
-	const std::string& scalarCollection,
-	const std::vector<std::string>& scalarNames,
+fmippStatus FMIComponentBackEnd::initializeVariables( std::vector<Type*>& variablePointers,
+	const fmippString& scalarCollection,
+	const std::vector<fmippString>& scalarNames,
 	const ScalarVariableAttributes::Causality::Causality causality )
 {
-	fmi2Status result = fmi2OK;
+	fmippStatus result = fmippOK;
 
 	// Clear the vector real inputs.
 	if ( false == variablePointers.empty() ) {
 		variablePointers.clear();
-		ipcLogger_->logger( fmi2Warning, "WARNING", "previous elements of input vector have been erased" );
+		ipcLogger_->logger( fmippWarning, "WARNING", "previous elements of input vector have been erased" );
 	}
 
 	if ( true == scalarNames.empty() ) return result;
@@ -794,7 +770,7 @@ fmi2Status FMIComponentBackEnd::initializeVariables( std::vector<Type*>& variabl
 	ipcSlave_->retrieveScalars( scalarCollection, scalars );
 
 	// Fill map between scalar names and instance pointers
-	std::map< std::string, ScalarVariable<Type>* > scalarMap;
+	std::map< fmippString, ScalarVariable<Type>* > scalarMap;
 	typename std::vector< ScalarVariable<Type>* >::iterator itScalar = scalars.begin();
 	typename std::vector< ScalarVariable<Type>* >::iterator endScalars = scalars.end();
 	for ( ; itScalar != endScalars; ++itScalar ) {
@@ -802,12 +778,12 @@ fmi2Status FMIComponentBackEnd::initializeVariables( std::vector<Type*>& variabl
 	}
 
 	// Iterators needed for searching the map.
-	typename std::map< std::string, ScalarVariable<Type>* >::const_iterator itFind;
-	typename std::map< std::string, ScalarVariable<Type>* >::const_iterator itFindEnd = scalarMap.end();
+	typename std::map< fmippString, ScalarVariable<Type>* >::const_iterator itFind;
+	typename std::map< fmippString, ScalarVariable<Type>* >::const_iterator itFindEnd = scalarMap.end();
 
 	// Loop through the input names, chack their causality and store pointer.
-	typename std::vector<std::string>::const_iterator itName = scalarNames.begin();
-	typename std::vector<std::string>::const_iterator itNamesEnd = scalarNames.end();
+	typename std::vector<fmippString>::const_iterator itName = scalarNames.begin();
+	typename std::vector<fmippString>::const_iterator itNamesEnd = scalarNames.end();
 	//Type** currentVariablePointer = variablePointers;
 	for ( ; itName != itNamesEnd; ++ itName )
 	{
@@ -819,16 +795,16 @@ fmi2Status FMIComponentBackEnd::initializeVariables( std::vector<Type*>& variabl
 		{
 			std::stringstream err;
 			err << "scalar variable not found: " << *itName;
-			ipcLogger_->logger( fmi2Fatal, "ABORT", err.str() );
-			result = fmi2Fatal;
+			ipcLogger_->logger( fmippFatal, "ABORT", err.str() );
+			result = fmippFatal;
 			break;
 		} else {
 			if ( causality != itFind->second->causality_ ) {
 				std::stringstream err;
 				err << "scalar variable '" << *itName << "' has wrong causality: "
 				    << itFind->second->causality_ << " instead of " << causality;
-				ipcLogger_->logger( fmi2Fatal, "ABORT", err.str() );
-				result = fmi2Warning;
+				ipcLogger_->logger( fmippFatal, "ABORT", err.str() );
+				result = fmippWarning;
 			}
 
 			/// \FIXME What about variability of scalar variable?
@@ -843,11 +819,9 @@ fmi2Status FMIComponentBackEnd::initializeVariables( std::vector<Type*>& variabl
 	return result;
 }
 
-
-
 template<typename Type>
-void FMIComponentBackEnd::getScalarNames( std::vector<std::string>& scalarNames,
-					  const std::string& scalarCollection,
+void FMIComponentBackEnd::getScalarNames( std::vector<fmippString>& scalarNames,
+					  const fmippString& scalarCollection,
 					  const ScalarVariableAttributes::Causality::Causality causality ) const
 {
 	scalarNames.clear();
@@ -865,5 +839,4 @@ void FMIComponentBackEnd::getScalarNames( std::vector<std::string>& scalarNames,
 	}
 }
 
-
 #endif // _FMIPP_FMICOMPONENTBACKEND_H
