@@ -1,5 +1,5 @@
 // -------------------------------------------------------------------
-// Copyright (c) 2013-2017, AIT Austrian Institute of Technology GmbH.
+// Copyright (c) 2013-2022, AIT Austrian Institute of Technology GmbH.
 // All rights reserved. See file FMIPP_LICENSE for details.
 // -------------------------------------------------------------------
 
@@ -33,7 +33,7 @@ public:
 	virtual ~IPCMasterLogger();
 
 	/// Call FMU logger.
-	virtual void logger( fmi2Status status, const std::string& category, const std::string& msg );
+	virtual void logger( fmippStatus status, const std::string& category, const std::string& msg );
 
 private:
 
