@@ -1,5 +1,5 @@
 // -------------------------------------------------------------------
-// Copyright (c) 2013-2017, AIT Austrian Institute of Technology GmbH.
+// Copyright (c) 2013-2022, AIT Austrian Institute of Technology GmbH.
 // All rights reserved. See file FMIPP_LICENSE for details.
 // -------------------------------------------------------------------
 
@@ -16,7 +16,7 @@ IPCMasterLogger::~IPCMasterLogger() {}
 
 
 void
-IPCMasterLogger::logger( fmi2Status status, const std::string& category, const std::string& msg )
+IPCMasterLogger::logger( fmippStatus status, const std::string& category, const std::string& msg )
 {
 	if ( 0 != frontend_ ) frontend_->logger( status, category, msg );
 }
