@@ -112,8 +112,10 @@ FMUModelExchange::FMUModelExchange( const fmippString& fmuDirUri,
 
 	if ( 0 != fmu_ ) {
 		readModelDescription();
-		integrator_->initialize();
-		integrator_->setType( type );
+		if ( 0 != nStateVars_ ) {
+			integrator_->initialize();
+			integrator_->setType( type );
+		}
 	} else {
 		lastStatus_ = fmi2Fatal;
 	}
@@ -169,8 +171,10 @@ FMUModelExchange::FMUModelExchange( const fmippString& modelIdentifier,
 
 	if ( 0 != fmu_ ) {
 		readModelDescription();
-		integrator_->initialize();
-		integrator_->setType( type );
+		if ( 0 != nStateVars_ ) {
+			integrator_->initialize();
+			integrator_->setType( type );
+		}
 	} else {
 		lastStatus_ = fmi2Fatal;
 	}
@@ -210,10 +214,12 @@ FMUModelExchange::FMUModelExchange( const FMUModelExchange& fmu ) :
 		lastStatus_( fmi2OK )
 {
 	if ( 0 != fmu_ ){
-		// allocate memory for the integrator
-		integrator_->initialize();
-		// create the stepper
-		integrator_->setType( fmu.integrator_->getProperties().type );
+		if ( 0 != nStateVars_ ) {
+			// allocate memory for the integrator
+			integrator_->initialize();
+			// create the stepper
+			integrator_->setType( fmu.integrator_->getProperties().type );
+		}
 	}
 }
 
@@ -468,6 +474,12 @@ fmippStatus FMUModelExchange::initialize( fmippBoolean toleranceDefined, double
 	// call newDiscreteStates to get the eventinfo
 	fmu_->functions->newDiscreteStates( instance_, eventinfo_ );
 
+	saveEventIndicators();
+
+	if ( fmi2True == eventinfo_->nextEventTimeDefined ) {
+		tnextevent_ = eventinfo_->nextEventTime;
+	}
+
 	// go into the "default mode": continuousTimeMode
 	lastStatus_ = enterContinuousTimeMode();
 
